@@ -2,7 +2,7 @@
 #
 # (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
 #
-# $Id: lib/Paranoid/IO.pm, 2.01 2016/06/23 00:34:49 acorliss Exp $
+# $Id: lib/Paranoid/IO.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -30,7 +30,7 @@ use Paranoid::Debug qw(:all);
 use Paranoid::Input;
 use IO::Handle;
 
-($VERSION) = ( q$Revision: 2.01 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.04 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 @EXPORT = qw(pclose pcloseAll popen preopen ptell pseek pflock pread
     pnlread pwrite pappend ptruncate);
@@ -751,7 +751,7 @@ Paranoid::IO - Paranoid IO support
 
 =head1 VERSION
 
-$Id: lib/Paranoid/IO.pm, 2.01 2016/06/23 00:34:49 acorliss Exp $
+$Id: lib/Paranoid/IO.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -815,7 +815,7 @@ The features provided by this module are:
 
 =item * File handle caching
 
-=item * Fork-safe file acess
+=item * Fork-safe file access
 
 =item * Inherent file locking
 
@@ -890,7 +890,7 @@ call) and file name.  This way you can still access the same file regardless
 of the process or its children's movements on the file system.
 
 This could be, however, a double-edged sword if your program intends to open
-indentically named files in multple locations.  If that is your intent you
+identically named files in multiple locations.  If that is your intent you
 would be cautioned to avoid using relative paths with I<popen>.
 
 =head1 SUBROUTINES/METHODS
@@ -960,7 +960,7 @@ fork.
 
 Called with a list of file names means that only those files are examined and
 reopened.  Any failure to reopen any single file handle will result in a false
-return value.  That said, any failures will not interupt the function from
+return value.  That said, any failures will not interrupt the function from
 trying every file in the list.
 
 =head2 pcloseAll
@@ -1015,7 +1015,7 @@ automatically.
     $bytes = pread($fh, $text, $length, $offset);
 
 This returns the number of bytes read, or undef on errors.  If this is called
-prior to an explict I<popen> it will default to a mode of B<O_RDONLY>.  Length
+prior to an explicit I<popen> it will default to a mode of B<O_RDONLY>.  Length
 defaults to B<PIOBLKSIZE>.
 
 =head2 pnlread
