@@ -2,7 +2,7 @@
 #
 # (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
 #
-# $Id: lib/Paranoid/Network.pm, 2.01 2016/06/23 00:34:49 acorliss Exp $
+# $Id: lib/Paranoid/Network.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -29,7 +29,7 @@ use Paranoid::Network::Socket;
 use Paranoid::Network::IPv4 qw(:all);
 use Paranoid::Network::IPv6 qw(:all);
 
-($VERSION) = ( q$Revision: 2.01 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.04 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 @EXPORT      = qw(ipInNetworks hostInDomains extractIPs netIntersect);
 @EXPORT_OK   = ( @EXPORT, qw(NETMATCH HOSTNAME_REGEX) );
@@ -192,8 +192,8 @@ sub extractIPs {
         # for IPv6 addresses
         if ( has_ipv6() or $] >= 5.012 ) {
 
-            @ips =
-                ( $string =~ m/(@{[ IPV6CIDRRGX ]}|@{[ IPV6REGEX ]})/sogix );
+            @ips = ( $string =~
+                    m/(@{[ IPV6CIDRRGX ]}|@{[ IPV6REGEX ]})/sogix );
 
             # Filter out addresses with more than one ::
             @ips = grep { scalar(m/(::)/sg) <= 1 } @ips;
@@ -267,7 +267,7 @@ Paranoid::Network - Network functions for paranoid programs
 
 =head1 VERSION
 
-$Id: lib/Paranoid/Network.pm, 2.01 2016/06/23 00:34:49 acorliss Exp $
+$Id: lib/Paranoid/Network.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
 
 =head1 SYNOPSIS
 
