@@ -1,8 +1,8 @@
 # Paranoid::Network::Socket -- Socket wrapper for seemless IPv6 support
 #
-# (c) 2005, Arthur Corliss <corliss@digitalmages.com>
+# (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
 #
-# $Id: Socket.pm,v 0.3 2012/05/29 21:38:37 acorliss Exp $
+# $Id: lib/Paranoid/Network/Socket.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -17,7 +17,7 @@
 
 package Paranoid::Network::Socket;
 
-use 5.006;
+use 5.008;
 
 use strict;
 use warnings;
@@ -25,7 +25,7 @@ use vars qw($VERSION @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use base qw(Exporter);
 use Socket qw(:all);
 
-($VERSION) = ( q$Revision: 0.3 $ =~ /(\d+(?:\.(\d+))+)/sm );
+($VERSION) = ( q$Revision: 2.04 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 #####################################################################
 #
@@ -36,7 +36,7 @@ use Socket qw(:all);
 our $ipv6_enabled;
 our $socket6;
 
-sub has_ipv6 () {
+sub has_ipv6 {
     return $ipv6_enabled;
 }
 
@@ -68,14 +68,14 @@ BEGIN {
             # because perl 5.12 has partial IPv6 support, and 5.14 full.  I
             # want to avoid redefined and prototype mismatch warnings.
             for my $symbol (@Socket6::EXPORT) {
-                unless ( grep /^$symbol$/sm, @EXPORT, @EXPORT_OK ) {
+                unless ( grep /^$symbol$/s, @EXPORT, @EXPORT_OK ) {
                     import Socket6 $symbol;
                     push @EXPORT, $symbol;
                     push @{ $EXPORT_TAGS{all} }, $symbol;
                 }
             }
             for my $symbol (@Socket6::EXPORT_OK) {
-                unless ( grep /^$symbol$/sm, @EXPORT, @EXPORT_OK ) {
+                unless ( grep /^$symbol$/s, @EXPORT, @EXPORT_OK ) {
                     import Socket6 $symbol;
                     push @EXPORT_OK, $symbol;
                     push @{ $EXPORT_TAGS{all} }, $symbol;
@@ -101,7 +101,7 @@ Paranoid::Network::Socket - Socket wrapper for seemless IPv6 support
 
 =head1 VERSION
 
-$Id: Socket.pm,v 0.3 2012/05/29 21:38:37 acorliss Exp $
+$Id: lib/Paranoid/Network/Socket.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
 
 =head1 SYNOPSIS
 
@@ -169,5 +169,5 @@ Arthur Corliss (corliss@digitalmages.com)
 This software is licensed under the same terms as Perl, itself. 
 Please see http://dev.perl.org/licenses/ for more information.
 
-(c) 2005, Arthur Corliss (corliss@digitalmages.com)
+(c) 2005 - 2015, Arthur Corliss (corliss@digitalmages.com)
 
