@@ -1,8 +1,8 @@
 # Paranoid::Process -- Process management support for paranoid programs
 #
-# (c) 2005 - 2015, Arthur Corliss <corliss@digitalmages.com>
+# (c) 2005 - 2016, Arthur Corliss <corliss@digitalmages.com>
 #
-# $Id: lib/Paranoid/Process.pm, 2.01 2016/06/23 00:34:50 acorliss Exp $
+# $Id: lib/Paranoid/Process.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
 #
 #    This software is licensed under the same terms as Perl, itself.
 #    Please see http://dev.perl.org/licenses/ for more information.
@@ -28,12 +28,13 @@ use Paranoid::Debug qw(:all);
 use POSIX qw(getuid setuid setgid WNOHANG setsid);
 use Carp;
 
-($VERSION) = ( q$Revision: 2.01 $ =~ /(\d+(?:\.\d+)+)/sm );
+($VERSION) = ( q$Revision: 2.04 $ =~ /(\d+(?:\.\d+)+)/sm );
 
 @EXPORT    = qw(switchUser daemonize);
 @EXPORT_OK = (
     @EXPORT, qw(MAXCHILDREN childrenCount installChldHandler
         sigchld pfork ptranslateUser ptranslateGroup pcapture
+        installSIGH uninstallSIGH installSIGD uninstallSIGD
         ) );
 %EXPORT_TAGS = (
     all   => [@EXPORT_OK],
@@ -41,7 +42,8 @@ use Carp;
         qw(MAXCHILDREN childrenCount installChldHandler
             sigchld pfork daemonize)
         ],
-        );
+    signal => [qw(installSIGH uninstallSIGH installSIGD uninstallSIGD)],
+    );
 
 #####################################################################
 #
@@ -49,6 +51,139 @@ use Carp;
 #
 #####################################################################
 
+{
+    my %signals = ( map { $_ => [] } keys %SIG );
+    my %original = %SIG;
+
+    sub _sigHandler {
+
+        # Purpose:  Runs all code refs assigned to the signal
+        # Returns:  Boolean
+        # Usage:    _sigHandler($signal);
+
+        my ( $signal, @sargs ) = @_;
+        my $sref;
+
+        local $SIG{$signal} = 'IGNORE';
+        foreach $sref ( @{ $signals{$signal} } ) {
+            &$sref( $signal, @sargs );
+        }
+
+        return 1;
+    }
+
+    sub installSIGD {
+
+        # Purpose:  Installs dispatcher for sig handlers that have code refs
+        #           assigned
+        # Returns:  Boolean
+        # Usage:    $rv = installSIGD();
+
+        my $sig;
+
+        pdebug( 'entering', PDLEVEL1 );
+        pIn();
+
+        foreach $sig ( keys %signals ) {
+            $SIG{$sig} = \&_sigHandler if scalar @{ $signals{$sig} };
+        }
+
+        pOut();
+        pdebug( 'leaving w/rv: 1', PDLEVEL1 );
+
+        return 1;
+    }
+
+    sub uninstallSIGD {
+
+        # Purpose:  Uninstalls the dispatcher
+        # Returns:  Boolean
+        # Usage:    $rv = uninstallSIGD();
+
+        pdebug( 'entering', PDLEVEL1 );
+        pIn();
+
+        foreach ( keys %original ) {
+            $SIG{$_} = $original{$_}
+                if defined $SIG{$_}
+                    and $SIG{$_} eq \&_sigHandler;
+        }
+
+        pOut();
+        pdebug( 'leaving w/rv: 1', PDLEVEL1 );
+
+        return 1;
+    }
+
+    sub installSIGH ($\&) {
+
+        # Purpose:  Assigns a code ref to a signal array
+        # Returns:  Boolean
+        # Usage:    $rv = installSIGH($signal, $sref);
+
+        my ( $signal, $sref ) = @_;
+        my $rv = 1;
+
+        pdebug( 'entering w/%s, %s', PDLEVEL1, $signal, $sref );
+        pIn();
+
+        if ( exists $signals{$signal} ) {
+            if ( grep { $_ eq $sref } @{ $signals{$signal} } ) {
+                pdebug( '%s handler already installed', PDLEVEL2, $signal );
+            } else {
+                push @{ $signals{$signal} }, $sref;
+                pdebug( '%s handler installed', PDLEVEL2, $signal );
+            }
+        } else {
+            pdebug( 'unknown signal: %s', PDLEVEL1, $signal );
+            $rv = 0;
+        }
+
+        pOut();
+        pdebug( 'leaving w/rv: %s', PDLEVEL1, $rv );
+
+        return $rv;
+    }
+
+    sub uninstallSIGH ($\&) {
+
+        # Purpose:  Removes a code ref for a signal array
+        # Returns:  Boolean
+        # Usage:    $rv = uninstallSIGH($signal, $sref);
+
+        my ( $signal, $sref ) = @_;
+        my $rv = 1;
+        my ( $sigh, $i );
+
+        pdebug( 'entering w/%s, %s', PDLEVEL1, $signal, $sref );
+        pIn();
+
+        if ( exists $signals{$signal} ) {
+            if ( grep { $_ eq $sref } @{ $signals{$signal} } ) {
+                $i = 0;
+                foreach $sigh ( @{ $signals{$signal} } ) {
+                    if ( $sigh eq $sref ) {
+                        splice @{ $signals{$signal} }, $i, 1;
+                        last;
+                    }
+                    $i++;
+                }
+                pdebug( '%s handler removed', PDLEVEL2, $signal );
+            } else {
+                pdebug( 'no %s handler to remove', PDLEVEL2, $signal );
+            }
+        } else {
+            pdebug( 'unknown signal: %s', PDLEVEL1, $signal );
+            $rv = 0;
+        }
+
+        pOut();
+        pdebug( 'leaving w/rv: %s', PDLEVEL1, $rv );
+
+        return $rv;
+    }
+}
+
 {
     my $maxChildren = 0;
     my $numChildren = 0;
@@ -87,12 +222,11 @@ sub sigchld {
     # Returns:  True (1)
     # Usage:    $SIG{CHLD} = \&sigchld;
 
-    my ( $osref, $pid );
+    my ($pid);
     my $sref = _chldHandler();
 
     # Remove the signal handler so we're not preempted
-    $osref = $SIG{CHLD};
-    $SIG{CHLD} = sub {1};
+    local $SIG{CHLD} = 'IGNORE';
 
     # Process children exit values
     do {
@@ -106,9 +240,6 @@ sub sigchld {
         }
     } until $pid < 1;
 
-    # Reinstall the signal handler
-    $SIG{CHLD} = $osref;
-
     return 1;
 }
 
@@ -393,11 +524,11 @@ Paranoid::Process - Process Management Functions
 
 =head1 VERSION
 
-$Id: lib/Paranoid/Process.pm, 2.01 2016/06/23 00:34:50 acorliss Exp $
+$Id: lib/Paranoid/Process.pm, 2.04 2016/09/19 15:00:25 acorliss Exp $
 
 =head1 SYNOPSIS
 
-  use Paranoid::Process;
+  use Paranoid::Process qw(:all);
 
   $rv = daemonize();
 
@@ -414,6 +545,15 @@ $Id: lib/Paranoid/Process.pm, 2.01 2016/06/23 00:34:50 acorliss Exp $
 
   $rv = pcapture($cmd, $crv, $out);
 
+  installSIGH('INT', &sigint1):
+  installSIGH('INT', &sigint2):
+  installSIGH('INT', &sigint3):
+
+  uninstallSIGH('INT', &sigint2);
+
+  installSIGD();
+  uninstallSIGD();
+
 =head1 DESCRIPTION
 
 This module provides a few functions meant to make life easier when managing
@@ -421,6 +561,7 @@ processes.  The following export targets are provided:
 
   all               All functions within this module
   pfork             All child management functions
+  signal            All signal dispatcher functions
 
 Only the functions B<switchUser> and B<daemonize> are currently exported by 
 default.
@@ -452,6 +593,10 @@ child's PID and exit value as arguments.
 
   $SIG{CHLD} = \&sigchld;
 
+  # Or, if using the signal dispatcher
+  installSIGH('CHLD', &sigchld);
+  installSIGD();
+
 This function decrements the child counter necessary for pfork's operation, as
 well as calling the user's signal handler with each child's PID and exit
 value.
@@ -490,13 +635,12 @@ by B<getgrent>.  If no match is found it returns undef.
 
 =head2 switchUser
 
+  $rv = switchUser($user);
   $rv = switchUser($user, $group);
 
 This function can be fed one or two arguments, both either named user or
 group, or UID or GID.  Both user and group arguments are optional as long as
-the other is called.  In other words, you can pass undef for one of the
-arguments, but not for both.  If you're only switching the user you can pass
-only the user argument.
+one of them is defined.
 
 =head2 pcapture
 
@@ -524,6 +668,35 @@ know ahead of time what kind of convoluted arguments you might be handing this
 call before system is called.  Failing to detaint that argument will cause
 your script to exit under taint mode.
 
+=head2 installSIGH
+
+  installSIGH($signal, &subroutine);
+
+This installs another subroutine in the queue for the specified signal.
+Subroutines are called in the order that they're added to the queue.  Adding
+a specific subroutine more than once is filtered out so each subroutine in the
+queue is unique.
+
+=head2 uninstallSIGH
+
+  uninstallSIGH($signal, &subroutine);
+
+Removes a subroutine from the specified queue.
+
+=head2 installSIGD
+
+  installSIGD();
+
+Inserts the dispatcher for each signal with subroutines in the queue.
+
+=head2 uninstallSIGD
+
+  uninstallSIGD();
+
+Removes the dispatcher for each signal that's using the dispatcher.  The
+signal handler installed is what ever was set when this module's code was
+loaded and initialized.
+
 =head1 DEPENDENCIES
 
 =over
@@ -586,11 +759,6 @@ For instance, to track the children's history in the parent:
 
 =head1 BUGS AND LIMITATIONS
 
-There's a bug in an current versions of Perl where B<ptranslateGroup> can 
-return negative numbers instead the actual GID.  This is due to the platform
-supporting unsigned integers for the GID, but Perl was casting it as a signed
-integer.  A patch has been submitted to blead-perl.
-
 On Solaris B<pcapture> doesn't return a -1 for non-existant commands, but a 0.
 On Linux this appears to work as intended.
 
@@ -603,5 +771,5 @@ Arthur Corliss (corliss@digitalmages.com)
 This software is licensed under the same terms as Perl, itself. 
 Please see http://dev.perl.org/licenses/ for more information.
 
-(c) 2005 - 2015, Arthur Corliss (corliss@digitalmages.com)
+(c) 2005 - 2016, Arthur Corliss (corliss@digitalmages.com)
 
